:mod:`dyff.models` --- Tools for creating containerized ML models
=================================================================

.. .. module:: dyff.models
..    :synopsis: Tools for creating containerized "inference services" from ML models.


.. .. automodule:: dyff.models.api
..    :members:

.. .. automodule:: dyff.models.sources
..    :members:

.. .. automodule:: dyff.models.bentoml
..    :members:

.. .. automodule:: dyff.models.frameworks
..    :members:

.. .. automodule:: dyff.models.frameworks.transformers
..    :members:

.. .. automodule:: dyff.models.outputs
..    :members:

.. .. automodule:: dyff.models.outputs.classification
..    :members:

.. .. automodule:: dyff.models.outputs.text
..    :members:
